@@ -58,7 +58,7 @@ class InlineJavaCallback {
 		StringBuffer cmdb = new StringBuffer("callback " + via + " " + method + " " + cast.getName()) ;
 		if (args != null){
 			for (int i = 0 ; i < args.length ; i++){
-				cmdb.append(" " + ijp.SerializeObject(args[i])) ;
+				cmdb.append(" " + ijp.SerializeObject(args[i], null)) ;
 			}
 		}
 		return cmdb.toString() ;
@@ -128,7 +128,7 @@ class InlineJavaCallback {
 				StringTokenizer st = new StringTokenizer(resp, " ") ;
 				String c = st.nextToken() ;
 				if (c.equals("callback")){
-					boolean thrown = new Boolean(st.nextToken()).booleanValue() ;
+					boolean thrown = Boolean.parseBoolean(st.nextToken()) ;
 					String arg = st.nextToken() ;
 					InlineJavaClass ijc = new InlineJavaClass(ijs, ijp) ;
 					ret = ijc.CastArgument(cast, arg) ;
