@@ -57,11 +57,12 @@ public class InlineJavaPerlObject extends InlineJavaPerlCaller {
 
 	protected void Dispose(boolean gc) throws InlineJavaPerlException, InlineJavaException {
 		if (id != 0){
-			CallPerlSub("Inline::Java::Callback::java_finalize", new Object [] {new Integer(id), new Boolean(gc)}) ;
+			CallPerlSub("Inline::Java::Callback::java_finalize", new Object [] {Integer.valueOf(id), Boolean.valueOf(gc)}) ;
 		}
 	}
 
-
+	/* unavoidable due to Perl reference-count behaviour */
+	@SuppressWarnings("deprecation")
 	protected void finalize() throws Throwable {
 		try {
 			Dispose(true) ;
